Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 94516)
+++ apps/app_voicemail.c	(working copy)
@@ -4006,29 +4006,33 @@
 	struct ast_flags config_flags = { CONFIG_FLAG_NOCACHE };
 
 	while ((cmd >= 0) && (cmd != 't') && (cmd != '*')) {
-		if (cmd)
-			retries = 0;
-		switch (cmd) {
-		case '1': 
-			/* prepend a message to the current message, update the metadata and return */
-		{
-			char msgfile[PATH_MAX];
-			char textfile[PATH_MAX];
-			int prepend_duration = 0;
-			struct ast_config *msg_cfg;
-			const char *duration_str;
+		char msgfile[PATH_MAX];
+		char textfile[PATH_MAX];
+		struct ast_config *msg_cfg = NULL;
+		const char *duration_str;
 
+		if (cmd == '1' || cmd == '2') {
 			make_file(msgfile, sizeof(msgfile), curdir, curmsg);
 			strcpy(textfile, msgfile);
 			strncat(textfile, ".txt", sizeof(textfile) - 1);
 			*duration = 0;
 
-			/* if we can't read the message metadata, stop now */
+			/* if we can't read the message metadata, replay menu */
 			if (!(msg_cfg = ast_config_load(textfile, config_flags))) {
 				cmd = 0;
-				break;
 			}
+			else if ((duration_str = ast_variable_retrieve(msg_cfg, "message", "duration")))
+				*duration = atoi(duration_str);
+		}
 
+		if (cmd)
+			retries = 0;
+		switch (cmd) {
+		case '1': 
+			/* prepend a message to the current message, update the metadata and return */
+		{
+			int prepend_duration = 0;
+
 			if (record_gain)
 				ast_channel_setoption(chan, AST_OPTION_RXGAIN, &record_gain, sizeof(record_gain), 0);
 
@@ -4036,10 +4040,6 @@
 			if (record_gain)
 				ast_channel_setoption(chan, AST_OPTION_RXGAIN, &zero_gain, sizeof(zero_gain), 0);
 
-			
-			if ((duration_str = ast_variable_retrieve(msg_cfg, "message", "duration")))
-				*duration = atoi(duration_str);
-
 			if (prepend_duration) {
 				struct ast_category *msg_cat;
 				/* need enough space for a maximum-length message duration */
@@ -4053,17 +4053,11 @@
 					STORE(curdir, vmu->mailbox, context, curmsg, chan, vmu, vmfmts, *duration, vms);
 				}
 			}
-
-			ast_config_destroy(msg_cfg);
-
 			break;
 		}
 		case '2': 
 			cmd = 't';
 			break;
-		case '*':
-			cmd = '*';
-			break;
 		default: 
 			cmd = ast_play_and_wait(chan,"vm-forwardoptions");
 				/* "Press 1 to prepend a message or 2 to forward the message without prepending" */
@@ -4077,6 +4071,8 @@
 			if (retries > 3)
 				cmd = 't';
 		}
+		if (msg_cfg)
+			ast_config_destroy(msg_cfg);
 	}
 	if (cmd == 't' || cmd == 'S')
 		cmd = 0;
